import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { JsonSchemaDrawer } from './drawer';

const checkForm = (formData: any): any => {
  return null;
};

const StepFourForm: React.ForwardRefRenderFunction<
  {
    getData: () => any;
  },
  { wizardData: any[] }
> = ({ wizardData }, ref) => {
  const [showSideBar, setShowSideBar] = useState(false);
  const [formData, setFormData] = useState<any>({});
  const [, setFormError] = useState<any>({});

  useImperativeHandle(ref, () => {
    return {
      getData: () => {
        const err = checkForm(formData);
        if (err) {
          setFormError(err);
          return null;
        }
        return formData;
      }
    };
  });

  return (
    <form>
      <div className="form-group">
        <label className="form-label" htmlFor="step-2-datasource">
          <span className="field-required" />
          路由策略
        </label>
        <select
          className="form-input"
          id="step-4-route"
          value={formData.route}
          onChange={evt =>
            setFormData({ ...formData, route: evt.target.value })
          }
        >
          <option value="" />
          <option value="first">第一个</option>
        </select>
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-block">
          <span className="field-required" />
          阻塞处理方式
        </label>
        <select
          className="form-input"
          id="step-4-block"
          value={formData.block}
          onChange={evt =>
            setFormData({ ...formData, block: evt.target.value })
          }
        >
          <option value="" />
          <option value="single">单机串行</option>
        </select>
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-timeout">
          <span className="field-required" />
          超时时间
        </label>
        <input
          className="form-input"
          type="number"
          id="step-4-timeout"
          value={formData.timeout}
          onChange={evt =>
            setFormData({ ...formData, timeout: evt.target.value })
          }
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-retry">
          <span className="field-required" />
          失败重试次数
        </label>
        <input
          className="form-input"
          type="number"
          id="step-4-retry"
          value={formData.retry}
          onChange={evt =>
            setFormData({ ...formData, retry: evt.target.value })
          }
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-starttime">
          <span className="field-required" />
          增量开始时间
        </label>
        <input
          className="form-input"
          type="text"
          id="step-4-starttime"
          value={formData.startTime}
          onChange={evt =>
            setFormData({ ...formData, startTime: evt.target.value })
          }
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-timefield">
          增量时间字段
        </label>
        <input
          className="form-input"
          type="text"
          id="step-4-timefield"
          value={formData.timeField}
          onChange={evt =>
            setFormData({ ...formData, timeField: evt.target.value })
          }
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-shardfield">
          分区字段
        </label>
        <input
          className="form-input"
          type="text"
          id="step-4-shardfield"
          value={formData.shardField}
          onChange={evt =>
            setFormData({ ...formData, shardField: evt.target.value })
          }
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-timerule">
          <span className="field-required" />
          定时规则
        </label>
        <input
          className="form-input"
          type="text"
          id="step-4-timerule"
          value={formData.timeRule}
          onChange={evt =>
            setFormData({ ...formData, timeRule: evt.target.value })
          }
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-4-taskname">
          <span className="field-required" />
          同步任务名称
        </label>
        <input
          className="form-input"
          type="text"
          id="step-4-taskname"
          value={formData.taskName}
          onChange={evt =>
            setFormData({ ...formData, taskName: evt.target.value })
          }
        />
      </div>
      <button
        type="button"
        className="drawer-button"
        onClick={() => setShowSideBar(true)}
      >
        构建
      </button>
      <JsonSchemaDrawer
        jsonSchema={wizardData.slice(0, 3).concat(formData)}
        show={showSideBar}
        onClose={() => setShowSideBar(false)}
      />
    </form>
  );
};

export const formConfig = {
  desc: '步骤4: 设置同步参数'
};

export default forwardRef(StepFourForm);
