import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { TableShemaDrawer } from './drawer';
import { useTableNames } from './service';

const HiveDetail: React.FunctionComponent<{
  value: any;
  onChange: (value: any) => void;
}> = ({ value, onChange }) => {
  return (
    <>
      <div className="form-group">
        <label className="form-label" htmlFor="step-1-path">
          <span className="field-required" />
          选择路径
        </label>
        <textarea
          className="form-input"
          id="step-1-path"
          placeholder="要读取的文件路径，如果要读取多个⽂件，可使用正确的表达式*"
          value={value.path}
          onChange={evt => onChange({ path: evt.target.value })}
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-1-hdfs">
          <span className="field-required" />
          HDFS
        </label>
        <input
          className="form-input"
          type="text"
          id="step-1-hdfs"
          value={value.hdfs}
          onChange={evt => onChange({ hdfs: evt.target.value })}
        />
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-1-filetype">
          <span className="field-required" />
          文件类型
        </label>
        <select
          className="form-input"
          id="step-1-filetype"
          value={value.filetype}
          onChange={evt => onChange({ filetype: evt.target.value })}
        >
          <option value="" />
          <option value="text">text</option>
          <option value="orc">orc</option>
        </select>
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-1-delim">
          分隔符
        </label>
        <input
          className="form-input"
          type="text"
          id="step-1-delim"
          value={value.delim}
          onChange={evt => onChange({ delim: evt.target.value })}
        />
      </div>
    </>
  );
};

const checkForm = (formData: any): any => {
  return null;
};

const StepTwoForm: React.ForwardRefRenderFunction<
  {
    getData: () => any;
  },
  { wizardData: any[] }
> = (props, ref) => {
  const [showSideBar, setShowSideBar] = useState(false);
  const [formData, setFormData] = useState<any>({});
  const [, setFormError] = useState<any>({});
  const dataSource = formData.dataSource || '';
  const { data: tableNames } = useTableNames(dataSource);
  // const loading = !tableNames && !fetchError;

  useImperativeHandle(ref, () => {
    return {
      getData: () => {
        const err = checkForm(formData);
        if (err) {
          setFormError(err);
          return null;
        }
        return formData;
      }
    };
  });

  let detail;
  if (dataSource === 'mysql') {
    detail = (
      <div className="form-group">
        <label className="form-label" htmlFor="step-2-presql">
          preSQL
        </label>
        <textarea
          className="form-input"
          id="step-2-fieldname"
          placeholder="preSQL"
          value={formData.preSql}
          onChange={evt =>
            setFormData({ ...formData, preSql: evt.target.value })
          }
        />
      </div>
    );
  } else if (dataSource === 'hive') {
    detail = (
      <HiveDetail
        value={formData}
        onChange={value => setFormData({ ...formData, ...value })}
      />
    );
  }
  return (
    <form>
      <div className="form-group">
        <label className="form-label" htmlFor="step-2-datasource">
          <span className="field-required" />
          选择数据源
        </label>
        <select
          className="form-input"
          id="step-2-datasource"
          value={dataSource}
          onChange={evt =>
            setFormData({ ...formData, dataSource: evt.target.value })
          }
        >
          <option value="" />
          <option value="mysql">MySQL</option>
          <option value="hive">Hive</option>
        </select>
      </div>
      <div className="form-group">
        <label className="form-label" htmlFor="step-2-datatable">
          <span className="field-required" />
          选择表
        </label>
        <select
          className="form-input"
          id="step-2-datatable"
          value={formData.tableName}
          onChange={evt =>
            setFormData({ ...formData, tableName: evt.target.value })
          }
        >
          <option value="" />
          {tableNames &&
            tableNames.map(tn => (
              <option key={tn} value={tn}>
                {tn}
              </option>
            ))}
        </select>
      </div>
      {detail}
      <button
        type="button"
        className="drawer-button"
        onClick={() => setShowSideBar(true)}
      >
        表结构预览
      </button>
      <TableShemaDrawer
        dataSource={dataSource}
        tableName={formData.tableName}
        show={showSideBar}
        onClose={() => setShowSideBar(false)}
      />
    </form>
  );
};

export const formConfig = {
  desc: '步骤2: 配置加载源'
};

export default forwardRef(StepTwoForm);
