import React, { useRef, useState } from 'react';
import StepOneForm, { formConfig as formConfig1 } from './StepOneForm';
import StepTwoForm, { formConfig as formConfig2 } from './StepTwoForm';
import StepThreeForm, { formConfig as formConfig3 } from './StepThreeForm';
import StepFourForm, { formConfig as formConfig4 } from './StepFourForm';

const forms = [StepOneForm, StepTwoForm, StepThreeForm, StepFourForm];
const configs = [formConfig1, formConfig2, formConfig3, formConfig4];

const StepController: React.FunctionComponent<{
  currentStep: number;
  onNext: () => void;
  onPrev: () => void;
}> = ({ currentStep, onNext, onPrev }) => {
  return (
    <div className="step-control-container">
      <button
        disabled={currentStep === 0}
        className="step-control"
        onClick={onPrev}
      >
        上一步
      </button>
      <button className="step-control" onClick={onNext}>
        {currentStep === 3 ? '完成' : '下一步'}
      </button>
    </div>
  );
};

export const SyncWizard: React.FunctionComponent<{
  onFinish: (data: any) => void;
}> = ({ onFinish }) => {
  const [currentStep, setCurrentStep] = useState(0);
  const [data, setData] = useState<any[]>([{}, {}, {}, {}]);

  const stepOneRef = useRef<{ getData: () => any }>(null);
  const stepTwoRef = useRef<{ getData: () => any }>(null);
  const stepThreeRef = useRef<{ getData: () => any }>(null);
  const stepFourRef = useRef<{ getData: () => any }>(null);

  const refs = [stepOneRef, stepTwoRef, stepThreeRef, stepFourRef];

  const stepHeaderItems = configs.map(({ desc }, idx) => {
    return (
      <li key={idx} className={currentStep === idx ? 'step-active' : ''}>
        <div className="step-index-item">
          <div className="step-index-label">{idx + 1}</div>
        </div>
        <div className="step-index-desc">{desc}</div>
      </li>
    );
  });

  const steps = forms.map((Form, idx) => (
    <div
      key={idx}
      className={
        'step-content-form ' + (currentStep === idx ? 'step-active' : '')
      }
    >
      <Form wizardData={data} ref={refs[idx]} />
    </div>
  ));

  return (
    <div className="sync-wizard">
      <ul className="step-index-list">{stepHeaderItems}</ul>
      <div className="step-content-container">{steps}</div>
      <StepController
        currentStep={currentStep}
        onPrev={() => setCurrentStep(currentStep - 1)}
        onNext={() => {
          const formData = refs[currentStep].current?.getData();
          if (!formData) {
            return;
          }
          const newData = data.slice();
          newData[currentStep] = formData;
          setData(newData);

          if (currentStep === 3) {
            onFinish(newData);
          } else {
            setCurrentStep(currentStep + 1);
          }
        }}
      />
    </div>
  );
};
