import useSWR from 'swr';
import * as mockData from './mockData';

export interface ITableSchemaResponse {
  field: string;
  type: string;
  length: number;
}

export interface IService<T> {
  data: T | undefined;
  error: any;
}

// mock
const tableSchemaFetcher = async (
  key: string
): Promise<ITableSchemaResponse[]> => {
  const [dataSource, , tableName] = key.split('/');
  if (!dataSource || !tableName) {
    return [];
  }
  // sleep 1
  await new Promise(resolve => setTimeout(resolve, 1));
  return mockData.tableSchema();
};

// mock
const tableNamesFetcher = async (key: string): Promise<string[]> => {
  const dataSource = key.split('/')[0];
  if (!dataSource) {
    return [];
  }
  // sleep 1
  await new Promise(resolve => setTimeout(resolve, 1));
  return mockData.tableNames();
};

export const useTableSchema = (
  dataSource: string,
  tableName: string
): IService<ITableSchemaResponse[]> => {
  const { data, error } = useSWR(
    `${dataSource}/tables/${tableName}`,
    tableSchemaFetcher
  );
  return { data, error };
};

export const useTableNames = (dataSource: string): IService<string[]> => {
  const { data, error } = useSWR(`${dataSource}/tables`, tableNamesFetcher);
  return { data, error };
};
